pm4py.algo.analysis.woflan.not\_well\_handled\_pairs package
============================================================

Submodules
----------

pm4py.algo.analysis.woflan.not\_well\_handled\_pairs.not\_well\_handled\_pairs module
-------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.analysis.woflan.not_well_handled_pairs.not_well_handled_pairs
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.analysis.woflan.not_well_handled_pairs
   :members:
   :undoc-members:
   :show-inheritance:
